@@ -305,6 +305,9 @@ def main(args=None):
         start_tag = None
         for tag in repo.get_tags():
             ver = parse_version(tag.name)
+            # account for case where no start tag and ver is same as upper_bound
+            if upper_bound and ver == upper_bound:
+                continue
             if (
                 not start_tag
                 or ver > parse_version(start_tag.name)
@@ -447,7 +450,7 @@ def parse_pr_body(body, release_notes, ref):
 
         # handle dependabot PRs
         if "Dependabot commands and options" in body:
-            category = "Dependency Updates"
+            category = "dependency updates"
             for line in body.splitlines():
                 if line.startswith("Bumps"):
                     release_notes.setdefault(category, []).append(
